@@ -29,6 +29,7 @@
 #include "SubtitleSystem.h"
 
 #include <ctime>
+#include <memory>
 
 /*
  *	constructeur
@@ -544,9 +545,12 @@ void Document::add_command(Command *cmd)
  */
 void Document::finish_command()
 {
-	CommandSystem::finish();
+	if(CommandSystem::is_recording())
+	{
+		CommandSystem::finish();
 
-	make_document_changed();
+		make_document_changed();
+	}
 }
 
 /*
