@@ -23,6 +23,8 @@
  *	along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 #include <gtkmm.h>
+#include "Player.h"
+#include "we/WaveformEditor.h"
 
 class Document;
 
@@ -50,6 +52,21 @@ public:
 	 */
 	virtual Document* get_current_document() = 0;
 
+	/*
+	 *
+	 */
+	virtual std::list<Document*> get_documents() = 0;
+
+	/*
+	 *
+	 */
+	virtual Player* get_player() = 0;
+
+	/*
+	 *
+	 */
+	virtual WaveformEditor* get_waveform_editor() = 0;
+
 	/*
 	 *
 	 */
