@@ -1,33 +1,25 @@
 /*
- *	subtitle editor
+ *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://kitone.free.fr/subtitleeditor/
+ *	http://home.gna.org/subtitleeditor/
+ *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2006, kitone
+ *	Copyright @ 2005-2008, kitone
  *
- *	Contact: kitone at free dot fr
- *
- *	This program is free software; you can redistribute it and/or
- *	modify it under the terms of the GNU General Public
- *	License as published by the Free Software Foundation; either
- *	version 2 of the License, or (at your option) any later version.
+ *	This program is free software; you can redistribute it and/or modify
+ *	it under the terms of the GNU General Public License as published by
+ *	the Free Software Foundation; either version 3 of the License, or
+ *	(at your option) any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the GNU
- *	General Public License for more details.
+ *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *	GNU General Public License for more details.
  *
- *	You should have received a copy of the GNU General Public
- *	License along with this program; if not, write to the Free Software
- *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA	02111-1307	USA
- *
- *	See gpl.txt for more information regarding the GNU General Public License.
- *
- *
- *	\file
- *	\brief 
- *	\author kitone (kitone at free dot fr)
+ *	You should have received a copy of the GNU General Public License
+ *	along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
+ 
 
 #include "SubtitleFormat.h"
 #include "Encodings.h"
@@ -37,14 +29,17 @@
 /*
  *
  */
-SubtitleFormat::SubtitleFormat(Document *doc)
-:m_scriptInfo(&doc->m_scriptInfo), 
-	m_subtitleModel(doc->m_subtitleModel), 
+SubtitleFormat::SubtitleFormat(Document *doc, const Glib::ustring &format_name)
+:	m_document(doc),
+	m_scriptInfo(&doc->m_scriptInfo), 
 	m_styleModel(doc->m_styleModel)
 {
 	m_use_auto_deteced = false;
 
 	Config::getInstance().get_value_string_list("encodings", "encodings", m_list_encodings);
+
+	set_newline(doc->getNewLine());
+	set_charset(doc->getCharset());
 }
 
 /*
@@ -54,17 +49,24 @@ SubtitleFormat::~SubtitleFormat()
 {
 }
 
+/*
+ *
+ */
+Glib::ustring SubtitleFormat::get_format_name()
+{
+	return m_format_name;
+}
 
 /*
  *
  */
 void SubtitleFormat::set_charset(const std::string &charset)
 {
-	se_debug(SE_DEBUG_LOADER | SE_DEBUG_SAVER);
-
 	m_charset = charset;
 
 	m_use_auto_deteced = charset.empty();
+
+	se_debug_message(SE_DEBUG_LOADER | SE_DEBUG_SAVER, "charset=[%s]", charset.c_str());
 }
 
 /*
@@ -72,34 +74,60 @@ void SubtitleFormat::set_charset(const std::string &charset)
  */
 std::string SubtitleFormat::get_charset()
 {
-	se_debug(SE_DEBUG_LOADER | SE_DEBUG_SAVER);
+	se_debug_message(SE_DEBUG_LOADER | SE_DEBUG_SAVER, "charset=[%s]", m_charset.c_str());
 
 	return m_charset;
 }
 
-	
 /*
  *
  */
-bool SubtitleFormat::open(const Glib::ustring &filename, const Glib::ustring &encoding)
+void SubtitleFormat::set_newline(const Glib::ustring &os)
 {
-	set_charset(encoding);
-	
-	se_debug_message(SE_DEBUG_LOADER, "<%s> (%s)", filename.c_str(), encoding.c_str());
+	if(os == "Unix")
+		m_newline = "\n";
+	else if(os == "Windows")
+		m_newline = "\r\n";
+	else
+	{
+		std::cerr << "SubtitleFormat can't found newline for [" << os << "]" << std::endl;
+		// default unix
+		m_newline = "\n";
+	}
+}
 
+/*
+ *	retour le '\n' ou '\r\n' selon la config du doc
+ *	"Unix", "Windows"
+ */
+std::string SubtitleFormat::get_newline()
+{
+	return m_newline;
+}
+
+/*
+ *
+ */
+bool SubtitleFormat::open(const Glib::ustring &filename)
+{
+	if(on_open(filename))
+	{
+		/*
+		m_document->setFilename(filename);
+		m_document->setCharset(get_charset());
+		m_document->setFormat(get_format_name());
+		*/
+		return true;
+	}
 	return false;
 }
 	
 /*
  *
  */
-bool SubtitleFormat::save(const Glib::ustring &filename, const Glib::ustring &encoding)
+bool SubtitleFormat::save(const Glib::ustring &filename)
 {
-	set_charset(encoding);
-
-	se_debug_message(SE_DEBUG_SAVER, "<%s> (%s)", filename.c_str(), encoding.c_str());
-
-	return false;
+	return on_save(filename);
 }
 
 /*
@@ -107,14 +135,16 @@ bool SubtitleFormat::save(const Glib::ustring &filename, const Glib::ustring &en
  */
 std::string convert_to_utf8_from_charset(const std::string &content, const std::string &charset)
 {
-	se_debug(SE_DEBUG_LOADER | SE_DEBUG_SAVER);
+	se_debug_message(SE_DEBUG_LOADER | SE_DEBUG_SAVER, "charset=[%s] content=[%s]", charset.c_str(), content.c_str());
 
 	// seulement si c'est de l'UTF-8 to UTF-8 on ne passe pas par une convertion
 	// juste une verification
 	if(charset == "UTF-8")
 	{
 		if(Glib::ustring(content).validate())
+		{
 			return content;
+		}
 		else
 		{
 			throw Glib::ConvertError(Glib::ConvertError::ILLEGAL_SEQUENCE, 
@@ -264,3 +294,11 @@ void SubtitleFormat::characters_to_newline(Glib::ustring &text, const Glib::ustr
 	find_and_replace(text, characters, "\n");
 }
 
+
+/*
+ *
+ */
+Document* SubtitleFormat::document()
+{
+	return m_document;
+}
