@@ -2,35 +2,27 @@
 #define _SubtitleModel_h
 
 /*
- *	subtitle editor
+ *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://kitone.free.fr/subtitleeditor/
+ *	http://home.gna.org/subtitleeditor/
+ *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2006, kitone
+ *	Copyright @ 2005-2008, kitone
  *
- *	Contact: kitone at free dot fr
- *
- *	This program is free software; you can redistribute it and/or
- *	modify it under the terms of the GNU General Public
- *	License as published by the Free Software Foundation; either
- *	version 2 of the License, or (at your option) any later version.
+ *	This program is free software; you can redistribute it and/or modify
+ *	it under the terms of the GNU General Public License as published by
+ *	the Free Software Foundation; either version 3 of the License, or
+ *	(at your option) any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the GNU
- *	General Public License for more details.
+ *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *	GNU General Public License for more details.
  *
- *	You should have received a copy of the GNU General Public
- *	License along with this program; if not, write to the Free Software
- *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA	02111-1307	USA
- *
- *	See gpl.txt for more information regarding the GNU General Public License.
- *
- *
- *	\file
- *	\brief 
- *	\author kitone (kitone at free dot fr)
+ *	You should have received a copy of the GNU General Public License
+ *	along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
+ 
 
 #include <gtkmm/liststore.h>
 #include "SubtitleTime.h"
@@ -89,7 +81,11 @@ public:
 		add(effect);
 		add(text);
 		add(translation);
-		add(characters_per_line);
+		add(characters_per_line_text);
+		add(characters_per_second_text);
+		add(characters_per_line_translation);
+		add(characters_per_second_translation);
+		add(note);
 	}
 
 	Gtk::TreeModelColumn<unsigned int>	 num;
@@ -112,9 +108,15 @@ public:
 	Gtk::TreeModelColumn<Glib::ustring>		text;
 
 	Gtk::TreeModelColumn<Glib::ustring>		translation;
-	Gtk::TreeModelColumn<Glib::ustring>		characters_per_line;
+	Gtk::TreeModelColumn<Glib::ustring>		characters_per_line_text;
+	Gtk::TreeModelColumn<Glib::ustring>		characters_per_line_translation;
+	Gtk::TreeModelColumn<Glib::ustring>		note;
+
+	Gtk::TreeModelColumn<Glib::ustring>		characters_per_second_text;
+	Gtk::TreeModelColumn<Glib::ustring>		characters_per_second_translation;
 };
 
+class Document;
 
 /*
  *
@@ -122,7 +124,7 @@ public:
 class SubtitleModel : public Gtk::ListStore
 {
 public:
-	SubtitleModel();
+	SubtitleModel(Document *doc);
 
 	/*
 	 * num = 0, start=end=0, ...
@@ -180,13 +182,13 @@ public:
 	/*
 	 *	recherche l'iterator precedant iter
 	 */
-	Gtk::TreeIter find_previous(Gtk::TreeIter &iter);
+	Gtk::TreeIter find_previous(const Gtk::TreeIter &iter);
 
 	/*
 	 *	recherche l'iterator suivant iter
 	 *	(c'est pour la forme dans notre cas un simple ++iter donne la solution)
 	 */
-	Gtk::TreeIter find_next(Gtk::TreeIter &iter);
+	Gtk::TreeIter find_next(const Gtk::TreeIter &iter);
 
 	/*
 	 *	FONCTION D'EDITION	******************************************************
@@ -195,12 +197,12 @@ public:
 	/*
 	 *	deplace tous les sous titres entre start et end de msecs.
 	 */
-	void move_in(unsigned int start, unsigned int end, unsigned int msecs);
+	//void move_in(unsigned int start, unsigned int end, unsigned int msecs);
 
 	/*
 	 *	deplace tous les sous titres a partir de start de msecs.
 	 */
-	void move_all(unsigned int start, unsigned int msecs);
+	//void move_all(unsigned int start, unsigned int msecs);
 	
 	/*
 	 *	insert sub avant iter et retourne l'iter de sub
@@ -234,8 +236,24 @@ public:
 	 *	check la colonne num pour init de [1,size]
 	 */
 	void rebuild_column_num();
+
 protected:
+
+	/*
+	 *
+	 */
+	virtual bool drag_data_delete_vfunc(const TreeModel::Path& path);
+
+	/*
+	 *
+	 */
+	virtual bool drag_data_received_vfunc(const TreeModel::Path& dest, const Gtk::SelectionData& selection_data);
+
+protected:
+	Document* m_document;
 	SubtitleColumnRecorder	m_column;
+
+	sigc::signal<void, const Gtk::TreePath&, const Gtk::TreePath&> m_my_signal_row_reorderer;
 };
 
 
