@@ -42,19 +42,27 @@ void on_current_document_changed(Document *doc)
 Application::Application(BaseObjectType *cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)//int argc, char *argv[])
 :Gtk::Window(cobject)
 {
-	//simple_test();
-
 	refGlade->get_widget_derived("statusbar", m_statusbar);
 
 	refGlade->get_widget("vbox-main", m_vboxMain);
-	refGlade->get_widget_derived("video-player", m_videoPlayer);
-	refGlade->get_widget_derived("waveform-system", m_waveform_system);
+	refGlade->get_widget("paned-multimedia", m_paned_multimedia);
+	refGlade->get_widget_derived("video-player", m_video_player);
+	refGlade->get_widget_derived("waveform-editor", m_waveform_editor);
 	refGlade->get_widget("notebook-documents", m_notebook_documents);
 
-	//m_notebook_documents->set_scrollable(true);
+	init_panel_multimedia();
 
 	set_default_size(800,600);
-	set_icon_from_file(get_share_dir("subtitleeditor.svg"));
+
+	// https://gna.org/bugs/?11449
+	try
+	{
+		set_icon_from_file(get_share_dir("subtitleeditor.svg"));
+	}
+	catch(const Glib::Error &ex)
+	{
+		std::cerr << "set_icon_from_file failed: " << ex.what() << std::endl;
+	}
 
 	m_vboxMain->pack_start(m_menubar, false, false);
 	m_vboxMain->reorder_child(m_menubar, 0);
@@ -79,8 +87,6 @@ Application::Application(BaseObjectType *cobject, const Glib::RefPtr<Gnome::Glad
 	Glib::ustring path_se_accelmap = get_config_dir("accelmap");
 	Gtk::AccelMap::load(path_se_accelmap);
 
-	m_waveform_system->set_video_player(m_videoPlayer->get_video_player());
-
 	ActionSystem::getInstance().signal_emit().connect(
 			sigc::mem_fun(*this, &Application::on_execute_action));
 
@@ -111,7 +117,6 @@ Application::Application(BaseObjectType *cobject, const Glib::RefPtr<Gnome::Glad
 				sigc::mem_fun(*this, &Application::notebook_drag_data_received));
 		m_notebook_documents->drag_dest_set(targets, Gtk::DEST_DEFAULT_ALL, Gdk::DragAction(GDK_ACTION_COPY | GDK_ACTION_MOVE));
 	}
-
 }
 
 /*
@@ -147,12 +152,6 @@ void Application::load_config()
 	if(value)
 		maximize();
 
-	cfg.get_value_bool("interface", "display-video-player", value);
-	set_display_video_player(value);
-
-	cfg.get_value_bool("interface", "display-waveform", value);
-	set_display_waveform(value);
-
 	// first launch
 	if(!cfg.has_group("encodings"))
 	{
@@ -178,13 +177,13 @@ void Application::load_config()
  */
 bool Application::on_delete_event(GdkEventAny *ev)
 {
+	se_debug(SE_DEBUG_APP);
+
 	bool res = Gtk::Window::on_delete_event(ev);
 
 	Glib::ustring path_se_accelmap = get_config_dir("accelmap");
 	Gtk::AccelMap::save(path_se_accelmap);
 
-	//return ask_to_save_on_exit();
-	
 	return res;
 }
 
@@ -545,20 +544,6 @@ void Application::on_config_interface_changed(const Glib::ustring &key, const Gl
 		else 
 			unmaximize();
 	}
-	else if(key == "display-video-player")
-	{
-		bool state;
-		from_string(value, state);
-
-		set_display_video_player(state);
-	}
-	else if(key == "display-waveform")
-	{
-		bool state;
-		from_string(value, state);
-
-		set_display_waveform(state);
-	}
 	else if(key == "used-autosave")
 	{
 		if(m_autosave_timeout)
@@ -583,72 +568,6 @@ void Application::on_config_interface_changed(const Glib::ustring &key, const Gl
 	}
 }
 
-/*
- *
- */
-bool Application::ask_to_save_on_exit()
-{
-	if(Config::getInstance().get_value_bool("interface", "ask-to-save-on-exit"))
-	{
-		/*
-		DocumentList docs = DocumentSystem::getInstance().getAllDocuments();
-		DocumentList::iterator it;
-		*/
-	}
-
-	return false;
-}
-
-/*
- *
- */
-void Application::set_display_video_player(bool state)
-{
-	Gtk::Paned *paned = dynamic_cast<Gtk::Paned*>(m_videoPlayer->get_parent());
-
-	g_return_if_fail(paned);
-
-	if(state)
-	{
-		m_videoPlayer->show();
-
-		if(!paned->is_visible())
-			paned->show();
-	}
-	else
-	{
-		m_videoPlayer->hide();
-
-		if(paned->get_child1()->is_visible() == false && paned->get_child2()->is_visible() == false)
-			paned->hide();
-	}
-}
-
-/*
- *
- */
-void Application::set_display_waveform(bool state)
-{
-	Gtk::Paned *paned = dynamic_cast<Gtk::Paned*>(m_waveform_system->get_parent());
-
-	g_return_if_fail(paned);
-
-	if(state)
-	{
-		m_waveform_system->show();
-
-		if(!paned->is_visible())
-			paned->show();
-	}
-	else
-	{
-		m_waveform_system->hide();
-
-		if(paned->get_child1()->is_visible() == false && paned->get_child2()->is_visible() == false)
-			paned->hide();
-	}
-}
-
 /*
  *
  */
@@ -749,7 +668,7 @@ void Application::init(OptionGroup &options)
 		{
 			Glib::ustring uri = Glib::filename_to_uri(utility::create_full_path(video));
 
-			m_videoPlayer->open(uri);
+			get_player()->open(uri);
 		}
 		catch(const Glib::Error &ex)
 		{
@@ -779,7 +698,7 @@ void Application::init(OptionGroup &options)
 		{
 			Glib::ustring uri = Glib::filename_to_uri(utility::create_full_path(waveform));
 
-			m_waveform_system->open(uri);
+			get_waveform_editor()->open_waveform(uri);
 		}
 		catch(const Glib::Error &ex)
 		{
@@ -848,3 +767,83 @@ Document* Application::get_current_document()
 	return DocumentSystem::getInstance().getCurrentDocument();
 }
 
+/*
+ *
+ */
+DocumentList Application::get_documents()
+{
+	return DocumentSystem::getInstance().getAllDocuments();
+}
+
+/*
+ *
+ */
+Player* Application::get_player()
+{
+	return m_video_player->player();
+}
+
+/*
+ *
+ */
+WaveformEditor* Application::get_waveform_editor()
+{
+	return m_waveform_editor;
+}
+
+/*
+ * Need to connect the visibility signal of the widgets children 
+ * (video player and waveform editor) for updating the visibility of 
+ * the paned multimedia widget.
+ */
+void Application::init_panel_multimedia()
+{
+	Gtk::Widget *child1 = m_paned_multimedia->get_child1();
+	Gtk::Widget *child2 = m_paned_multimedia->get_child2();
+
+	if(child1)
+	{
+		child1->signal_show().connect(
+			sigc::mem_fun(*this, &Application::on_paned_multimedia_visibility_child_changed));
+		child1->signal_hide().connect(
+			sigc::mem_fun(*this, &Application::on_paned_multimedia_visibility_child_changed));
+	}
+
+	if(child2)
+	{
+		child2->signal_show().connect(
+			sigc::mem_fun(*this, &Application::on_paned_multimedia_visibility_child_changed));
+		child2->signal_hide().connect(
+			sigc::mem_fun(*this, &Application::on_paned_multimedia_visibility_child_changed));
+	}
+
+	// first check
+	on_paned_multimedia_visibility_child_changed();
+}
+
+/*
+ * Check the state visibility of the children. 
+ * When one child is show the panel is also show.
+ * When both chidren are hide, the panel is hide.
+ * This callback are connected to signals 
+ * 'signal_show' and 'signal_hide' of the children.
+ */
+void Application::on_paned_multimedia_visibility_child_changed()
+{
+	Gtk::Widget *child1 = m_paned_multimedia->get_child1();
+	Gtk::Widget *child2 = m_paned_multimedia->get_child2();
+
+	bool state1 = false;
+	bool state2 = false;
+
+	if(child1 != NULL)
+		state1 = child1->is_visible();
+	if(child2 != NULL)
+		state2 = child2->is_visible();
+
+	if(state1 || state2)
+		m_paned_multimedia->show();
+	else
+		m_paned_multimedia->hide();
+}
+
