@@ -156,103 +156,12 @@ void MenuBar::create(Gtk::Window &window, Statusbar &statusbar)
 				_("Launch the errors checking"));
 	}
 
-	// menu-video
-	{
-		ActionGroup ag("video-player", m_refUIManager);
-
-		ag.item("menu-video", _("_Video"));
-	
-		ag.item("video-player/open", Gtk::Stock::OPEN, _("_Open Movie"), 
-				_("Open the video"), "<Shift><Control>M");
-		ag.item("video-player/play", Gtk::Stock::MEDIA_PLAY,
-				_("_Play the video"));
-		ag.item("video-player/pause", Gtk::Stock::MEDIA_PAUSE, 
-				_("_Make a pause"));
-		ag.item("video-player/play-pause", Gtk::Stock::MEDIA_PLAY, 
-				_("_Play / Pause"), _("Play or make a pause"));
-
-		ag.item("video-player/seek-to-selection", _("_Seek To Selection"),
-				_("Seek to the first selected subtitle"));
-
-		ag.item("video-player/play-previous-subtitle", Gtk::Stock::MEDIA_PREVIOUS, _("Play _Previous Subtitle"), 
-				_("Play previous subtitle from the first selected subtitle"));
-		ag.item("video-player/play-current-subtitle", Gtk::Stock::MEDIA_PLAY, _("Play _Selection"), 
-				_("Play the selected subtitle"));
-		ag.item("video-player/play-next-subtitle", Gtk::Stock::MEDIA_NEXT, _("Play _Next Subtitle"), 
-				_("Play next subtitle from the first selected subtitle"));
-	
-		ag.item("video-player/play-previous-second", _("Play Previous Second"));
-		ag.item("video-player/play-first-second", _("Play First Second"));
-		ag.item("video-player/play-last-second", _("Play Last Second"));
-		ag.item("video-player/play-next-second", _("Play Next Second"));
-
-		ag.item("video-player/set-subtitle-start", _("Set Subtitle _Start"));
-		ag.item("video-player/set-subtitle-end", _("Set Subtitle _End"));
-
-		ag.item("video-player/menu-backwards-jump", Gtk::Stock::MEDIA_REWIND, _("_Backards Jump"));
-		ag.item("video-player/very-short-backwards-jump", _("Very Short"));
-		ag.item("video-player/short-backwards-jump", _("Short"));
-		ag.item("video-player/medium-backwards-jump", _("Medium"));
-		ag.item("video-player/long-backwards-jump", _("Long"));
-
-		ag.item("video-player/menu-forward-jump", Gtk::Stock::MEDIA_FORWARD, _("_Forward Jump"));
-		ag.item("video-player/very-short-forward-jump", _("Very Short"));
-		ag.item("video-player/short-forward-jump", _("Short"));
-		ag.item("video-player/medium-forward-jump", _("Medium"));
-		ag.item("video-player/long-forward-jump", _("Long"));
-	}
-
-	// menu-waveform
-	{
-		ActionGroup ag("waveform", m_refUIManager);
-
-		ag.item("menu-waveform", _("_Waveform"));
-	
-		ag.item("waveform/open", Gtk::Stock::OPEN, _("_Open Waveform"), _("Open wavefrom from a file or create from a video"), "<Control><Alt>O");
-		ag.item("waveform/save", Gtk::Stock::SAVE, _("_Save Waveform"), _("Save waveform to file"), "<Control><Alt>S");
-
-		ag.item("waveform/zoom-in", Gtk::Stock::ZOOM_IN, _("Zoom _In"));
-		ag.item("waveform/zoom-out", Gtk::Stock::ZOOM_OUT, _("Zoom _Out"));
-		ag.item("waveform/zoom-selection", Gtk::Stock::ZOOM_FIT, _("Zoom _Selection"));
-		ag.item("waveform/zoom-all", Gtk::Stock::ZOOM_100, _("Zoom _All"));
-
-		ag.item("waveform/center-with-selected-subtitle", _("_Center With Selected Subtitle"));
-
-		addToggleAction("waveform/scrolling-with-cursor", _("Scrolling With _Cursor"), "waveform", "scrolling-with-cursor");
-		addToggleAction("waveform/scrolling-with-selection", _("Scrolling With _Selection"), "waveform", "scrolling-with-selection");
-	}
 
 	// menu-view
 	{
 		ActionGroup ag("view", m_refUIManager);
 
 		ag.item("menu-view", _("V_iew"));
-
-		ag.item("view/simple", _("_Simple"));
-		ag.item("view/advanced", _("_Advanced"));
-		ag.item("view/translation", _("_Translation"));
-		ag.item("view/timing", _("T_iming"));
-
-		addToggleAction("display-video-player", _("_Video Player"), "interface", "display-video-player");
-		addToggleAction("display-waveform", _("_Waveform"), "interface", "display-waveform");
-
-		ag.item("menu-columns", _("Columns"));
-
-		addToggleActionColumn("number", _("Number"));
-		addToggleActionColumn("layer", _("Layer"));
-		addToggleActionColumn("start", _("Start"));
-		addToggleActionColumn("end", _("End"));
-		addToggleActionColumn("duration", _("Duration"));
-		addToggleActionColumn("style", _("Style"));
-		addToggleActionColumn("name", _("Name"));
-		addToggleActionColumn("margin-r", _("Margin Left"));
-		addToggleActionColumn("margin-l", _("Margin Right"));
-		addToggleActionColumn("margin-v", _("Margin Vertical"));
-		addToggleActionColumn("effect", _("Effect"));
-		addToggleActionColumn("text", _("Text"));
-		addToggleActionColumn("translation", _("Translation"));
-		addToggleActionColumn("note", _("Note"));
-		addToggleActionColumn("cps", _("Characters Per Second"));
 	}
 	
 	// menu-option
@@ -295,9 +204,6 @@ void MenuBar::create(Gtk::Window &window, Statusbar &statusbar)
 
 	create_ui_from_file();
 
-	Config::getInstance().signal_changed("subtitle-view").connect(
-			sigc::mem_fun(*this, &MenuBar::on_config_subtitle_view_changed));
-
 	ActionSystem::getInstance().signal_sensitive_changed().connect(
 			sigc::mem_fun(*this, &MenuBar::set_sensitive));
 
@@ -324,28 +230,6 @@ MenuBar::~MenuBar()
 {
 }
 
-
-/*
- *
- */
-void MenuBar::addToggleActionColumn(const Glib::ustring &name, const Glib::ustring &label	)
-{
-	bool default_value = false;
-
-	Glib::RefPtr<Gtk::Action> action = Gtk::ToggleAction::create(name, label);
-	Glib::RefPtr<Gtk::ToggleAction> toggle_action = Glib::RefPtr<Gtk::ToggleAction>::cast_static(action);
-
-	if(Config::getInstance().get_value_bool("subtitle-view", Glib::ustring("show-column-") + name, default_value))
-		toggle_action->set_active(default_value);
-
-	sigc::slot<void> slot = sigc::bind<Glib::ustring>(
-			sigc::mem_fun(*this, &MenuBar::on_setup_view_toggled), name);
-
-	m_connections[name] = action->signal_activate().connect(slot);
-
-	m_refActionGroup->add(action);
-}
-
 /*
  *
  */
@@ -394,79 +278,6 @@ void MenuBar::execute(const Glib::ustring &name)
 		bool value = action->get_active();
 		Config::getInstance().set_value_bool("interface", "display-video-player", value);
 	}
-	else if(name == "display-waveform")
-	{
-		Glib::RefPtr<Gtk::ToggleAction> action = 
-			Glib::RefPtr<Gtk::ToggleAction>::cast_static(m_refActionGroup->get_action(name));
-
-		bool value = action->get_active();
-		
-		Config::getInstance().set_value_bool("interface", "display-waveform", value);
-	}
-	else if(name == "waveform/scrolling-with-cursor")
-	{
-		Glib::RefPtr<Gtk::ToggleAction> action = 
-			Glib::RefPtr<Gtk::ToggleAction>::cast_static(m_refActionGroup->get_action(name));
-
-		bool value = action->get_active();
-
-		Config::getInstance().set_value_bool("waveform", "scrolling-with-cursor", value);
-	}
-	else if(name == "waveform/scrolling-with-selection")
-	{
-		Glib::RefPtr<Gtk::ToggleAction> action = 
-			Glib::RefPtr<Gtk::ToggleAction>::cast_static(m_refActionGroup->get_action(name));
-
-		bool value = action->get_active();
-
-		Config::getInstance().set_value_bool("waveform", "scrolling-with-selection", value);
-	}
-}
-
-
-// FILE
-
-/*
- *
- */
-void MenuBar::on_setup_view_toggled(const Glib::ustring &column)
-{
-	Glib::RefPtr<Gtk::ToggleAction> action = 
-		Glib::RefPtr<Gtk::ToggleAction>::cast_static(m_refActionGroup->get_action(column));
-
-	if(action)
-	{
-		sigc::connection connection = m_connections[column];
-
-		bool state = action->get_active();
-	
-		connection.block();
-	
-		Config::getInstance().set_value_bool("subtitle-view", Glib::ustring("show-column-")+column, state);
-		
-		connection.unblock();
-	}
-}
-
-/*
- *
- */
-void MenuBar::set_toggle_column(const Glib::ustring &column, bool state)
-{
-	try
-	{
-		Glib::RefPtr<Gtk::ToggleAction> action = 
-			Glib::RefPtr<Gtk::ToggleAction>::cast_static(m_refActionGroup->get_action(column));
-
-		if(action)
-		{
-			Config::getInstance().set_value_bool("subtitle-view", Glib::ustring("show-column-")+column, state);
-		}
-	}
-	catch(Glib::Error &ex)
-	{
-		std::cerr << ex.what() << std::endl;
-	}
 }
 
 /*
@@ -481,31 +292,6 @@ void MenuBar::on_preferences()
 	delete dialog;
 }
 
-/*
- *
- */
-void MenuBar::on_config_subtitle_view_changed(const Glib::ustring &key, const Glib::ustring &value)
-{
-	//std::cout << build_message("%s %s %s %s", __FILE__, __FUNCTION__, key.c_str(), value.c_str()) << std::endl;
-	
-	if(key.find("show-column-") != Glib::ustring::npos)
-	{
-		Glib::ustring column = key;
-		column.erase(0, Glib::ustring("show-column-").size());
-
-		Glib::RefPtr<Gtk::ToggleAction> action = 
-			Glib::RefPtr<Gtk::ToggleAction>::cast_static(m_refActionGroup->get_action(column));
-
-		bool state;
-		if(from_string(value, state))
-		{
-			m_connections[column].block();
-			action->set_active(state);
-			m_connections[column].unblock();
-		}
-	}
-}
-
 /*
  *
  */
