@@ -568,7 +568,48 @@ namespace Gst
 		g_free(str);
 		return res;
 	}
+
+	/*
+	 * Display a message for missing plugins.
+	 */
+	void dialog_missing_plugins(const std::list<Glib::ustring> &list)
+	{
+		Glib::ustring plugins;
+		
+		std::list<Glib::ustring>::const_iterator it = list.begin();
+		std::list<Glib::ustring>::const_iterator end = list.end();
+
+		while(it != end)
+		{
+			plugins += *it;
+			plugins += "\n";
+			++it;
+		}
+
+		Glib::ustring msg = _(
+					"GStreamer plugins missing.\n"
+					"The playback of this movie requires the following decoders "
+					"which are not installed:");
+
+		dialog_error(msg, plugins);
+
+		se_debug_message(SE_DEBUG_UTILITY, "%s %s", msg.c_str(), plugins.c_str());
+	}
 	
+	/*
+	 * Checks if the element exists and whether its version is at least the version required.
+	 * Display a dialog error if failed.
+	 */
+	bool check_registry(const Glib::ustring &name, int min_major, int min_minor, int min_micro)
+	{
+		if(gst_default_registry_check_feature_version(name.c_str(), min_major, min_minor, min_micro))
+			return true;
+
+		dialog_error(
+				build_message(_("Failed to create a GStreamer element '%s'."), name.c_str()),
+				_("Please check your GStreamer installation."));
+		return false;
+	}
 }
 
 namespace utility
@@ -634,6 +675,34 @@ namespace utility
 		}
 	}
 
+	void usplit(const Glib::ustring &str, const Glib::ustring::value_type &delimiter, std::vector<Glib::ustring> &container)
+	{
+		Glib::ustring::const_iterator it = str.begin(), end = str.end(), first;
+
+		for(first = it; it != end; ++it)
+		{
+			if(delimiter == *it)
+			{
+				if(first != it) // || keep_blank)
+				{
+					// extract the current field from the string
+					container.push_back(Glib::ustring(first, it));
+					// skip the next delimiter
+					first = it; ++first;
+				}
+				else
+					++first;
+			}
+		}
+
+		if(first != it) // || keep_blank
+		{
+			// extract the last field from the string
+			container.push_back(Glib::ustring(first, it));
+		}
+	}
+
+
 	/*
 	 *	transforme test/file.srt en /home/toto/test/file.srt 
 	 */
