@@ -230,6 +230,11 @@ namespace utility
 	 */
 	void split(const std::string &str, const char &c, std::vector<std::string> &array, int max=-1);
 
+	/*
+	 * Split with best utf8 support...
+	 */
+	void usplit(const Glib::ustring &str, const Glib::ustring::value_type &delimiter, std::vector<Glib::ustring> &container);
+
 	/*
 	 *	transforme test/file.srt en /home/toto/test/file.srt 
 	 */
@@ -271,6 +276,17 @@ namespace Gst
 	 *	retourne le temps en string par rapport au temps nsecs (gstreamer)
 	 */
 	Glib::ustring time_to_string (gint64 time);
+
+	/*
+	 * Display a message for missing plugins.
+	 */
+	void dialog_missing_plugins(const std::list<Glib::ustring> &missings);
+
+	/*
+	 * Checks if the element exists and whether its version is at least the version required.
+	 * Display a dialog error if failed.
+	 */
+	bool check_registry(const Glib::ustring &name, int min_major, int min_minor, int min_micro);
 }
 
 /*
